<?php
// Generate QR Code
function generateQRCode($text, $size = 300) {
    $data = urlencode($text);
    $qrCodeUrl = "https://chart.googleapis.com/chart?chs={$size}x{$size}&cht=qr&chl={$data}";
    return $qrCodeUrl;
}

// Generate Barcode (Code 128)
function generateBarcode($text) {
    $barcode = imagecreatetruecolor(800, 150); // Update the image dimensions as desired
    $background = imagecolorallocate($barcode, 255, 255, 255);
    $color = imagecolorallocate($barcode, 0, 0, 0);
    imagefilledrectangle($barcode, 0, 0, 799, 149, $background);

    $font = 'fonts/fre3of9x.ttf'; // Replace with the actual path to a font file
    $textColor = imagecolorallocate($barcode, 0, 0, 0);
    $fontSize = 80; // Update the font size as desired
    $textBoundingBox = imagettfbbox($fontSize, 0, $font, $text);
    $textWidth = $textBoundingBox[2] - $textBoundingBox[0];
    $textHeight = $textBoundingBox[1] - $textBoundingBox[7];
    $textX = 0 - $textBoundingBox[0]; // Adjust the text position based on the bounding box
    $textY = (150 - $textHeight) / 2 + $textHeight; // Center the text vertically

    imagettftext($barcode, $fontSize, 0, $textX, $textY, $textColor, $font, $text);

    // Crop the image to remove white space
    $croppedBarcode = imagecropauto($barcode, IMG_CROP_WHITE);

    ob_start();
    imagepng($croppedBarcode);
    $barcodeImage = ob_get_clean();
    imagedestroy($barcode);
    imagedestroy($croppedBarcode);

    return 'data:image/png;base64,' . base64_encode($barcodeImage);
}

// Process form submission
$codeImage = null;
$codeType = null;
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['code_type']) && isset($_POST['text'])) {
        $codeType = $_POST['code_type'];
        $text = $_POST['text'];
        if ($codeType === 'qr_code') {
            $codeImage = generateQRCode($text);
        } elseif ($codeType === 'barcode') {
            $codeImage = generateBarcode($text);
        }
    }
}

// Function to force file download
function forceDownload($file) {
    if (file_exists($file)) {
        header('Content-Description: File Transfer');
        header('Content-Type: application/octet-stream');
        header('Content-Disposition: attachment; filename="' . basename($file) . '"');
        header('Expires: 0');
        header('Cache-Control: must-revalidate');
        header('Pragma: public');
        header('Content-Length: ' . filesize($file));
        readfile($file);
        exit;
    }
}
?>

<?php include "header.php"?>
<?php include "nav.php"?>

<div class="container" style="background: rgb(255 255 255 / 90%);padding: 18px;">
    <div class="row">
        <div class="col-md-6 mx-auto">
          
            <form method="post" class="my-4">
                <div class="form-group">
                    <label for="code_type">Code Type:</label>
                    <select id="code_type" name="code_type" class="form-control">
                        <option value="qr_code">QR Code</option>
                        <option value="barcode">Barcode</option>
                    </select>
                </div>
                <div class="form-group">
                    <label for="text">Text:</label>
                    <input type="text" id="text" name="text" class="form-control" required
                           value="<?php echo isset($_POST['text']) ? htmlspecialchars($_POST['text']) : ''; ?>">
                </div>

                <button type="submit" class="btn btn-success submit_button">Generate Now</button>
            </form>

            <?php if (isset($codeImage)): ?>
                <div style="text-align:center;">
                    <h2 class="mt-4">Generated Code</h2>
                    <?php if ($codeType === 'qr_code'): ?>
                        <img id="generatedImage" src="<?php echo $codeImage; ?>" alt="Generated QR Code"
                             class="img-fluid">
                        <a id="downloadQRCodeButton" class="btn btn-primary" download="qr_code.png"
                           href="<?php echo $codeImage; ?>" style="margin-top:10px;">Download QR Code</a>
                    <?php elseif ($codeType === 'barcode'): ?>
                        <img id="generatedImage" src="<?php echo $codeImage; ?>" alt="Generated Barcode"
                             class="img-fluid">
                        <a id="downloadBarcodeButton" class="btn btn-primary" download="barcode.png"
                           href="<?php echo $codeImage; ?>" style="margin-top:10px;">Download Barcode</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
    document.getElementById('downloadQRCodeButton').addEventListener('click', function () {
        forceDownload('<?php echo $codeImage; ?>');
    });
</script>

</div>
</div>

 <?php include"more_tools.php"?>
  
</div>
</div>

 </div>
    </div>
  </div>

    </div>



  <div class="container" id="faq">
  <?php include"mostafa-content.php"?>
</div>
<?php include"footer.php"?>

</body>
</html>

