<?php
if ($_SERVER["REQUEST_METHOD"] === "POST") {
    $url = $_POST["url"];
    $page_content = file_get_contents($url);

    if ($page_content === false) {
        echo "Unable to fetch the page content.";
    } else {
        // Function to extract meta tags
        function getMetaTags($html) {
            $meta_tags = [];
            $doc = new DOMDocument();
            @$doc->loadHTML($html);

            $meta_elements = $doc->getElementsByTagName('meta');
            foreach ($meta_elements as $meta) {
                $name = $meta->getAttribute('name');
                $content = $meta->getAttribute('content');
                if (!empty($name)) {
                    $meta_tags[$name] = $content;
                }
            }

            return $meta_tags;
        }

        // Function to extract title tag
        function getTitleTag($html) {
            $doc = new DOMDocument();
            @$doc->loadHTML($html);

            $title_elements = $doc->getElementsByTagName('title');
            if ($title_elements->length > 0) {
                return $title_elements->item(0)->nodeValue;
            } else {
                return "Title tag not found.";
            }
        }

        // Function to calculate SEO score
        function calculateSEOScore($html) {
            $keywords = ['your', 'target', 'keywords']; // Replace with your target keywords
            $heading_counts = [];
            for ($i = 1; $i <= 6; $i++) {
                $tag = 'h' . $i;
                $heading_counts[$tag] = substr_count(strtolower($html), "<$tag>");
            }

            // Count images with and without alt tags
            $doc = new DOMDocument();
            @$doc->loadHTML($html);
            $img_elements = $doc->getElementsByTagName('img');
            $images_with_alt = 0;
            $images_without_alt = 0;
            foreach ($img_elements as $img) {
                if (empty($img->getAttribute('alt'))) {
                    $images_without_alt++;
                } else {
                    $images_with_alt++;
                }
            }

            // Check which heading tags are missing
            $missing_headings = [];
            for ($i = 1; $i <= 6; $i++) {
                $tag = 'h' . $i;
                if ($heading_counts[$tag] === 0) {
                    $missing_headings[] = $tag;
                }
            }

            $keyword_density = 0;
            foreach ($keywords as $keyword) {
                $keyword_density += substr_count(strtolower($html), $keyword);
            }

            // Normalize the SEO score to a 0-100 range
            $seo_score = ($heading_counts['h1'] * 10) + ($images_without_alt * 5) + ($keyword_density * 2);
            $seo_score = min(100, $seo_score); // Ensure the score does not exceed 100

            return [$heading_counts, $images_with_alt, $images_without_alt, $missing_headings, $seo_score];
        }

        list($heading_counts, $images_with_alt, $images_without_alt, $missing_headings, $seo_score) = calculateSEOScore($page_content);

        // Function to extract meta title
        function getMetaTitle($html) {
            $doc = new DOMDocument();
            @$doc->loadHTML($html);

            $title_elements = $doc->getElementsByTagName('title');
            if ($title_elements->length > 0) {
                return $title_elements->item(0)->nodeValue;
            } else {
                return "Title tag not found.";
            }
        }

        // Function to extract meta description
        function getMetaDescription($html) {
            $doc = new DOMDocument();
            @$doc->loadHTML($html);

            $meta_elements = $doc->getElementsByTagName('meta');
            foreach ($meta_elements as $meta) {
                if ($meta->getAttribute('name') === 'description') {
                    return $meta->getAttribute('content');
                }
            }

            return "Meta description not found.";
        }

        // Function to extract meta keywords
        function getMetaKeywords($html) {
            $doc = new DOMDocument();
            @$doc->loadHTML($html);

            $meta_elements = $doc->getElementsByTagName('meta');
            foreach ($meta_elements as $meta) {
                if ($meta->getAttribute('name') === 'keywords') {
                    return $meta->getAttribute('content');
                }
            }

            return "Meta keywords not found.";
        }

        $meta_title = getMetaTitle($page_content);
        $meta_description = getMetaDescription($page_content);
        $meta_keywords = getMetaKeywords($page_content);

        $meta_keywords_error = '';
        $meta_keyword_count = count(explode(',', $meta_keywords));
        if ($meta_keyword_count === 0) {
            $meta_keywords_error = 'Meta keywords are missing. Consider adding relevant meta keywords to improve SEO.';
        } elseif ($meta_keyword_count > 10) {
            $meta_keywords_error = 'You have more than 10 meta keywords. As a general rule, it is recommended to use no more than about 10 meta keywords for a single page.';
        }

        $base_url = parse_url($url, PHP_URL_SCHEME) . '://' . parse_url($url, PHP_URL_HOST);

        $robots_txt_url_http = $base_url . '/robots.txt';
        $sitemap_url_http = $base_url . '/sitemap.xml';

        $robots_txt_url_https = 'https://' . parse_url($url, PHP_URL_HOST) . '/robots.txt';
        $sitemap_url_https = 'https://' . parse_url($url, PHP_URL_HOST) . '/sitemap.xml';

        $robots_txt_exists_http = false;
        $sitemap_exists_http = false;
        $robots_txt_exists_https = false;
        $sitemap_exists_https = false;

        try {
            $robots_headers_http = @get_headers($robots_txt_url_http);
            if ($robots_headers_http && strpos($robots_headers_http[0], '200 OK') !== false) {
                $robots_txt_exists_http = true;
            }

            $sitemap_headers_http = @get_headers($sitemap_url_http);
            if ($sitemap_headers_http && strpos($sitemap_headers_http[0], '200 OK') !== false) {
                $sitemap_exists_http = true;
            }

            $robots_headers_https = @get_headers($robots_txt_url_https);
            if ($robots_headers_https && strpos($robots_headers_https[0], '200 OK') !== false) {
                $robots_txt_exists_https = true;
            }

            $sitemap_headers_https = @get_headers($sitemap_url_https);
            if ($sitemap_headers_https && strpos($sitemap_headers_https[0], '200 OK') !== false) {
                $sitemap_exists_https = true;
            }
        } catch (Exception $e) {
            echo "Error: " . $e->getMessage();
        }

        if (!$robots_txt_exists_http && !$robots_txt_exists_https) {
            $seo_score -= 10; // Deduct 10 points if robots.txt is missing
        }

        if (!$sitemap_exists_http && !$sitemap_exists_https) {
            $seo_score -= 10; // Deduct 10 points if sitemap.xml is missing
        }

        $deductions = 0;

        // Deduct points if the title length is less than 10 characters
        if (strlen($meta_title) < 10) {
            $deductions += 10;
        }

        // Deduct points if the title length exceeds 70 characters
        if (strlen($meta_title) > 70) {
            $deductions += 10;
        }

        // Deduct points if the meta description exceeds 160 characters
        if (strlen($meta_description) > 160) {
            $deductions += 10;
        }

        // Deduct points if the meta description is below 150 characters
        if (strlen($meta_description) < 150) {
            $deductions += 10;
        }

        // Deduct points for each image without alt tags
        $deductions += $images_without_alt * 5;

        // Deduct points for exceeding the recommended number of meta keywords (10)
        if ($meta_keyword_count > 10) {
            $deductions += 10;
        }

        // Calculate the final SEO score
        $seo_score -= $deductions;

        // Display the overall SEO score
        echo '<div class="overall-score">';
        echo 'Overall SEO Score: ' . round($seo_score, 2) . '/100';
        echo '</div>';

        // Calculate the progress percentage
        $progress_percentage = min(100, max(0, $seo_score));

        // Define color based on the progress percentage
        $progress_color = '';
        if ($progress_percentage >= 80) {
            $progress_color = 'green';
        } elseif ($progress_percentage >= 70) {
            $progress_color = 'light-orange-and-green';
        } elseif ($progress_percentage >= 50) {
            $progress_color = 'orange';
        } elseif ($progress_percentage >= 30) {
            $progress_color = 'light-orange';
        } else {
            $progress_color = 'red';
        }

        // Display the rounded progress bar with the specified color class
        echo '<div class="progress-bar">';
        echo '<div class="progress ' . $progress_color . '" style="width: ' . $progress_percentage . '%;"></div>';
        echo '</div>';

        $cards = [
            [
                'title' => 'Title Tag',
                'content' => $meta_title,
                'length' => strlen($meta_title), // Ensure 'length' is defined
                'description' => 'Ideally, your title tag should contain between 10 and 70 characters (spaces included). Make sure your title is explicit and contains your most important keywords. Be sure that each page has a unique title.',
            ],
            [
                'title' => 'Meta Description',
                'content' => $meta_description,
                'length' => strlen($meta_description), // Ensure 'length' is defined
                'description' => 'The meta description should be between 150 and 160 characters (including spaces). It should provide a concise and meaningful summary of your page content.',
            ],
            [
                'title' => 'Meta Keywords',
                'content' => $meta_keywords,
                'length' => strlen($meta_keywords), // Ensure 'length' is defined
                'description' => $meta_keywords_error,
            ],
            [
                'title' => 'Total Images with Alt Tags',
                'content' => $images_with_alt,
                'description' => 'Having alt tags for images is good for SEO. You have ' . $images_with_alt . ' image(s) with alt tag(s).',
            ],
            [
                'title' => 'Total Images without Alt Tags',
                'content' => $images_without_alt,
                'description' => 'Images without alt tags can impact SEO negatively. You have ' . $images_without_alt . ' image(s) without alt tag(s).',
            ],
            [
                'title' => 'Robots.txt',
                'content' => ($robots_txt_exists_http ? "Without SSL  <a href='$robots_txt_url_http' target='_blank'>$robots_txt_url_http</a><br>" : "Without SSL  Not found<br>") . 
                             ($robots_txt_exists_https ? "With SSL  <a href='$robots_txt_url_https' target='_blank'>$robots_txt_url_https</a>" : "With SSL  Not found"),
                'description' => 'The robots.txt file instructs search engine crawlers on how to interact with your site. Make sure it is correctly configured.',
            ],
            [
                'title' => 'Sitemap.xml',
                'content' => ($sitemap_exists_http ? "Without SSL <a href='$sitemap_url_http' target='_blank'>$sitemap_url_http</a><br>" : "Without SSL Not found<br>") . 
                             ($sitemap_exists_https ? "With SSL  <a href='$sitemap_url_https' target='_blank'>$sitemap_url_https</a>" : "With SSL  Not found"),
                'description' => 'A sitemap helps search engines index your site. Ensure it is up to date and accessible.',
            ],
            [
                'title' => 'Missing Heading Tags',
                'content' => !empty($missing_headings) ? 'Missing: ' . implode(', ', array_map('htmlspecialchars', $missing_headings)) : 'None',
                'description' => 'Heading tags (e.g., &lt;h1&gt;, &lt;h2&gt;) provide structure to your content. Make sure to include them for better SEO.',
            ],
        ];

         foreach ($cards as $card) {
            // Ensure that 'length' is defined before using it
            $statusClass = (isset($card['length']) && $card['length'] >= 10 && $card['length'] <= 70) ? 'good-status' : 'bad-status';

            echo '<div class="seo-card card">';
            echo '<div class="card-body">';
            echo '<h5 class="card-title">' . $card['title'] . ' <i class="fas fa-info-circle" data-bs-toggle="tooltip" data-bs-placement="top" title="' . $card['description'] . '"></i></h5>';
            echo "<p class='card-text $statusClass'>" . $card['content'] . "</p>";

            if ($statusClass === 'bad-status') {
                echo '<div class="alert alert-danger" role="alert">' . $card['description'] . '</div>';
            }

            echo '</div>';
            echo '</div>';
        }
    }
}
?>
