<?php
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if any image files were uploaded
    if (isset($_FILES['image']) && is_array($_FILES['image']['tmp_name'])) {
        // Get the selected extension, quality, and dimensions from the form
        $extension = $_POST['extension'];
        $quality = isset($_POST['quality']) ? $_POST['quality'] : '';
        $width = isset($_POST['width']) ? (int)$_POST['width'] : 0;
        $height = isset($_POST['height']) ? (int)$_POST['height'] : 0;
        $percentage = isset($_POST['percentage']) ? (int)$_POST['percentage'] : 0;
        $maintainAspectRatio = isset($_POST['maintain_aspect_ratio']) ? true : false;

        // Check if the selected extension is valid
        $allowedExtensions = array('jpg', 'jpeg', 'png', 'gif');
        if (!in_array($extension, $allowedExtensions)) {
            echo json_encode(array('success' => false, 'message' => 'Invalid extension.'));
            exit;
        }

        // Process each uploaded image
        $outputFolder = 'output/';
        $resultUrls = array();

        foreach ($_FILES['image']['tmp_name'] as $index => $tmpName) {
            $originalFileName = $_FILES['image']['name'][$index];
            $originalFileExtension = strtolower(pathinfo($originalFileName, PATHINFO_EXTENSION));

            // Check if the uploaded file has a valid image extension
            if (!in_array($originalFileExtension, $allowedExtensions)) {
                echo json_encode(array('success' => false, 'message' => 'Invalid image file: ' . $originalFileName));
                exit;
            }

            // Generate a unique filename for the saved image
            $uniqueString = substr(md5(uniqid()), 0, 4);
            $outputFileName = "resized-$originalFileName-$uniqueString.$extension";
            $outputFilePath = $outputFolder . $outputFileName;

            // Convert and save the image with the selected extension
            if ($originalFileExtension === 'jpg' || $originalFileExtension === 'jpeg') {
                $sourceImage = imagecreatefromjpeg($tmpName);
            } elseif ($originalFileExtension === 'png') {
                $sourceImage = imagecreatefrompng($tmpName);
            } elseif ($originalFileExtension === 'gif') {
                $sourceImage = imagecreatefromgif($tmpName);
            }

            if (!$sourceImage) {
                echo json_encode(array('success' => false, 'message' => 'Failed to create source image.'));
                exit;
            }

            // Get the original image dimensions
            $originalWidth = imagesx($sourceImage);
            $originalHeight = imagesy($sourceImage);

            // Calculate the target dimensions based on the entered width and height
            if ($width > 0 && $height > 0) {
                if ($maintainAspectRatio) {
                    // Calculate the aspect ratio of the entered width and height
                    $aspectRatio = $width / $height;

                    // Compare the aspect ratio with the original image
                    $originalAspectRatio = $originalWidth / $originalHeight;

                    if ($aspectRatio > $originalAspectRatio) {
                        $targetWidth = $originalWidth;
                        $targetHeight = round($originalWidth / $aspectRatio);
                    } else {
                        $targetWidth = round($originalHeight * $aspectRatio);
                        $targetHeight = $originalHeight;
                    }
                } else {
                    // Use the entered width and height without maintaining aspect ratio
                    $targetWidth = $width;
                    $targetHeight = $height;
                }
            } elseif ($percentage > 0) {
                // Calculate the target dimensions based on the percentage value
                $targetWidth = round($originalWidth * $percentage / 100);
                $targetHeight = round($originalHeight * $percentage / 100);
            } else {
                // Use the original dimensions if width, height, and percentage are not specified
                $targetWidth = $originalWidth;
                $targetHeight = $originalHeight;
            }

            // Create a new image with the target dimensions
            $resizedImage = imagecreatetruecolor($targetWidth, $targetHeight);

            // Resize the original image to the target dimensions
            imagecopyresampled($resizedImage, $sourceImage, 0, 0, 0, 0, $targetWidth, $targetHeight, $originalWidth, $originalHeight);

            // Set the image quality
            if ($extension === 'jpg' || $extension === 'jpeg') {
                $quality = (int)$quality; // Cast $quality to an integer
                imagejpeg($resizedImage, $outputFilePath, $quality);
            } elseif ($extension === 'png') {
                imagepng($resizedImage, $outputFilePath, round(9 * $quality / 100));
            } elseif ($extension === 'gif') {
                imagegif($resizedImage, $outputFilePath);
            }

            imagedestroy($sourceImage);
            imagedestroy($resizedImage);

            $resultUrls[] = $outputFilePath;
        }

        // Return the URLs of the saved images
        echo json_encode(array('success' => true, 'urls' => $resultUrls));
        exit;
    }
}
?>

<?php include"header.php"?>
<?php include"nav.php"?>
<style>
       
        #fileInput {
            display: none;
        }
    </style>

<div class="container" style="background: rgb(255 255 255 / 90%);padding: 18px;">
    <div class="row">
        <div class="col-md-6 mx-auto">
           <h3 style="text-align: center;">Batch Image Resize and Compression</h3>
        <!-- <p style="text-align: center;">Resize or Compress your images to Small size with entered dimension. </p> -->

            <form id="image-form" method="POST" enctype="multipart/form-data">
                <div id="dropzone" class="p-5 text-center">
                    <p class="mb-3">Drag and drop image files here</p>
                    <div class="form-group">
                        <label for="fileInput" class="btn btn-primary">Browse Files</label>
                        <input type="file" id="fileInput" name="image[]" accept="image/*" multiple onchange="showSelectedImages(event.target.files)">
                    </div>
                </div>

                <div id="selected-images-list">
                    <div id="processList"></div>
                </div>

                <label for="dimension_type">Dimension Input Type:</label><br>
                <input type="radio" id="dimension_width_height" name="dimension_type" value="wh" checked onchange="updateDimensionType()">
                <label for="dimension_width_height">Width / Height</label><br>
                <input type="radio" id="dimension_percentage" name="dimension_type" value="percentage" onchange="updateDimensionType()">
                <label for="dimension_percentage">Percentage</label><br><br>

                <div id="width-height-container" class="row">
                    <div class="col">
                        <label for="width">Width:</label>
                        <input type="number" id="width" name="width" class="form-control" value="500" required> 
                    </div>
                    <div class="col">
                        <label for="height">Height:</label>
                        <input type="number" id="height" name="height" class="form-control" value="500" required>
                    </div>
                </div>

                <div id="percentage-container" style="display: none;">
                    <label for="percentage">In Ratio :</label>
                    <input type="range" id="percentage-range" name="percentage" min="1" max="100" required oninput="updatePercentageValue()" class="form-range">
                    <span id="percentage-value">50%</span><br><br>
                </div>

                <!--input type="checkbox" id="maintain-aspect-ratio" name="maintain_aspect_ratio">
                <label for="maintain-aspect-ratio">Maintain Aspect Ratio</label><br><br-->

                <label for="quality">Quality:</label>
                <input type="range" id="quality" name="quality" min="1" max="100" required oninput="updateQualityValue()" class="form-range">
                <span id="quality-value">50%</span><br><br>

                <label for="extension">Save Image Extension as:</label>
                <select id="extension" name="extension" class="form-select">
                    <option>Please Select</option>
                    <option value="jpg">JPG</option>
                    <option value="jpeg">JPEG</option>
                    <option value="png">PNG</option>
                    <option value="gif">GIF</option>
                    <!-- Add support for other image extensions as needed -->
                </select>
                <br><br>

                <input type="submit" value="Resize and Compress Image" class="btn btn-primary" id="convert">
            </form>
       

<div class="container mt-4">
    <div id="progress-bar" style="display: none;">
        <div class="progress">
            <div id="progress-bar-inner" class="progress-bar progress-bar-striped progress-bar-animated" role="progressbar" style="width: 0%">0%</div>
        </div>
    </div>
    <div id="result"></div>
     <div style="display: flex; justify-content: space-between;">
          <button class="btn btn-primary" id="download" style="display: none;">Download All</button>
          <button class="btn btn-primary" id="download-zip" style="display: none;">Download Zip</button>
        </div><br><br>
</div>

 </div>
    </div>
  </div>

<?php include"includes/ad_header.php"?>

<?php include"more_tools.php"?>

    </div>
  
  <div class="container" id="faq">
  <?php include"mostafa-content.php"?>
</div>
<?php include"footer.php"?>
<script>
var dropzone = document.getElementById('dropzone');
var resultDiv = document.getElementById('result');
var downloadButton = document.getElementById('download');
var downloadButtonZip = document.getElementById('download-zip');
var extensionSelect = document.getElementById('extension');
var convertButton = document.getElementById('convert');
var fileInput = document.getElementById('fileInput');
var widthInput = document.getElementById('width');
var heightInput = document.getElementById('height');
var percentageRange = document.getElementById('percentage-range');
var qualityRange = document.getElementById('quality');
var selectedExtension = '';
var selectedFiles = [];
var allowedExtensions = ['jpg', 'jpeg', 'png', 'gif']; // Add more allowed extensions if needed

dropzone.addEventListener('dragover', function (e) {
    e.preventDefault();
    dropzone.style.border = '2px dashed #aaa';
});

dropzone.addEventListener('dragleave', function () {
    dropzone.style.border = '2px dashed #ccc';
});

dropzone.addEventListener('drop', function (e) {
    e.preventDefault();
    dropzone.style.border = '2px dashed #ccc';
    resultDiv.innerHTML = '';
    downloadButton.style.display = 'none';
    downloadButtonZip.style.display = 'none';

    var files = e.dataTransfer.files;
    displaySelectedFiles(files);
});

extensionSelect.addEventListener('change', function () {
    selectedExtension = extensionSelect.value;
    if (selectedExtension === '') {
        convertButton.disabled = true;
    } else {
        convertButton.disabled = false;
    }
});

fileInput.addEventListener('change', function () {
    var files = fileInput.files;
    displaySelectedFiles(files);
});

function displaySelectedFiles(files) {
    if (files.length === 0) {
        alert('Please select image file(s).');
        return;
    }

    for (var i = 0; i < files.length; i++) {
        var file = files[i];
        var fileExtension = getFileExtension(file.name);

        if (!allowedExtensions.includes(fileExtension.toLowerCase())) {
            alert('Invalid extension. Skipping file: ' + file.name);
            continue;
        }

        selectedFiles.push(file);
        var listItem = document.createElement('div');
        listItem.classList.add('selected-item', 'd-flex', 'align-items-center');
        listItem.innerHTML = `
            <div class="thumbnail-container me-2">
                <img src="${URL.createObjectURL(file)}" class="thumbnail" alt="Thumbnail" style="width:80px;height:40px;padding:5px;">
            </div>
            <div>
                <p class="mb-1">${file.name}</p>
                <p class="mb-0" style="font-size:12px;color:#7a7c7e">${formatBytes(file.size)}</p>
                <p class="mb-0" style="font-size:12px;color:#7a7c7e">Dimensions: <span id="dimension-${i}">Unknown x Unknown</span></p>
            </div>
            <button onclick="removeSelectedFile(${i})" class="btn btn-warning btn-sm ms-auto">Remove</button>
        `;
        processList.appendChild(listItem);

        processList.style.maxHeight = '200px';
        processList.style.overflowY = 'scroll';

        // Read the file to get its dimensions
        var reader = new FileReader();
        reader.onload = (function (index) {
            return function (e) {
                var img = new Image();
                img.onload = function () {
                    var dimensionSpan = document.getElementById(`dimension-${index}`);
                    dimensionSpan.textContent = `${img.naturalWidth} x ${img.naturalHeight}`;
                };
                img.src = e.target.result;
            };
        })(i);
        reader.readAsDataURL(file);
    }
}

function removeSelectedFile(index) {
    selectedFiles.splice(index, 1);
    processList.removeChild(processList.children[index]);

    // Reset the index of each child element
    for (var i = index; i < processList.children.length; i++) {
        processList.children[i].querySelector('button').setAttribute('onclick', `removeSelectedFile(${i})`);
    }
}

function convertImages(event) {
    event.preventDefault();

    if (selectedFiles.length === 0) {
        alert('Please select image file(s).');
        return;
    }

    if (selectedExtension === '') {
        alert('Please select a valid extension.');
        return;
    }

    var formData = new FormData();
    formData.append('extension', selectedExtension);

    for (var i = 0; i < selectedFiles.length; i++) {
        formData.append('image[]', selectedFiles[i]);
    }

    var dimensionType = document.querySelector('input[name="dimension_type"]:checked').value;

    if (dimensionType === 'wh') {
        var width = widthInput.value;
        var height = heightInput.value;
        formData.append('width', width);
        formData.append('height', height);
    } else if (dimensionType === 'percentage') {
        var percentage = percentageRange.value;
        formData.append('percentage', percentage);
    }

    var quality = qualityRange.value;
    formData.append('quality', quality);

    var xhr = new XMLHttpRequest();
    xhr.open('POST', window.location.href, true);

    // Track upload progress
    xhr.upload.addEventListener('progress', function (event) {
        if (event.lengthComputable) {
            var percentComplete = (event.loaded / event.total) * 100;
            updateProgressBar(percentComplete);
        }
    });

    xhr.onreadystatechange = function () {
        if (xhr.readyState === XMLHttpRequest.DONE) {
            hideProgressBar(); // Hide the progress bar once the request is complete

            if (xhr.status === 200) {
                var response = JSON.parse(xhr.responseText);
                if (response.success) {
                    resultDiv.innerHTML = '';
                    downloadButton.style.display = 'block';
                    downloadButtonZip.style.display = 'block';
                    var urls = response.urls;
                    var extensionGroups = groupImagesByExtension(urls);
                    for (var ext in extensionGroups) {
                        var images = extensionGroups[ext];
                        var extDiv = document.createElement('div');
                        extDiv.className = 'col-md-12 mb-4';
                        var rowDiv = document.createElement('div');
                        rowDiv.className = 'row g-4';
                        for (var i = 0; i < images.length; i++) {
                            var imgDiv = document.createElement('div');
                            imgDiv.className = 'col-md-3';
                            var img = document.createElement('img');
                            img.src = images[i];
                            img.className = 'thumbnail w-100';
                            var fileName = getFileNameFromUrl(images[i]);
                            var nameDiv = document.createElement('div');
                            nameDiv.className = 'conv-img-title';
                            nameDiv.innerText = fileName;
                            imgDiv.appendChild(img);
                            imgDiv.appendChild(nameDiv);
                            rowDiv.appendChild(imgDiv);

                            // Display dimension and file size
                            var fileInfoDiv = document.createElement('div');
                            fileInfoDiv.className = 'conv-img-title';
                            fileInfoDiv.innerHTML = `
                                <p class="mb-0">Dimensions: <span id="dimension-${ext}-${i}">Unknown x Unknown</span></p>
                                <p class="mb-0">Size: ${getFileSizeString(images[i])}</p>
                            `;
                            imgDiv.appendChild(fileInfoDiv);

                            // Read the image to get its dimensions
                            var image = new Image();
                            image.onload = (function (ext, i) {
                                return function () {
                                    var dimensionSpan = document.getElementById(`dimension-${ext}-${i}`);
                                    dimensionSpan.textContent = `${this.naturalWidth} x ${this.naturalHeight}`;
                                };
                            })(ext, i);
                            image.src = images[i];
                        }
                        extDiv.appendChild(rowDiv);
                        resultDiv.appendChild(extDiv);
                    }
                    // Show success message
                    var successMessage = document.createElement('div');
                    successMessage.className = 'alert alert-success mt-4';
                    successMessage.innerText = 'Conversion successful!';
                    resultDiv.appendChild(successMessage);

                    // Show note message
                    var noteMessage = document.createElement('div');
                    noteMessage.className = 'alert alert-danger mt-2';
                    noteMessage.innerText = 'Note: These images will be deleted in 1 hour.';
                    resultDiv.appendChild(noteMessage);
                } else {
                    resultDiv.innerHTML = response.message;
                    downloadButton.style.display = 'none';
                    downloadButtonZip.style.display = 'none';
                }
            } else {
                resultDiv.innerHTML = 'Error occurred during conversion. Please try again later.';
                downloadButton.style.display = 'none';
                downloadButtonZip.style.display = 'none';
            }
        }
    };

    // Show the progress bar
    showProgressBar();

    xhr.send(formData);
}

// Place the JavaScript code here
function updateDimensionType() {
    var widthHeightContainer = document.getElementById('width-height-container');
    var percentageContainer = document.getElementById('percentage-container');

    var dimensionType = document.querySelector('input[name="dimension_type"]:checked').value;

    if (dimensionType === 'wh') {
        widthHeightContainer.style.display = 'flex';
        percentageContainer.style.display = 'none';
    } else if (dimensionType === 'percentage') {
        widthHeightContainer.style.display = 'none';
        percentageContainer.style.display = 'block';
    }
}

// Call the updateDimensionType function initially to set the default display
updateDimensionType();

// Place the JavaScript code here
function updateQualityValue() {
    var qualityValue = document.getElementById('quality-value');
    var quality = qualityRange.value;
    qualityValue.textContent = quality + '%';
}

function updatePercentageValue() {
    var percentageValue = document.getElementById('percentage-value');
    var percentage = percentageRange.value;
    percentageValue.textContent = percentage + '%';
}

// Add event listeners to the quality and percentage range sliders
qualityRange.addEventListener('input', updateQualityValue);

percentageRange.addEventListener('input', updatePercentageValue);

// Call the updateQualityValue and updatePercentageValue functions initially to set the default values
updateQualityValue();
updatePercentageValue();

function getFileNameFromUrl(url) {
    var parts = url.split('/');
    return parts[parts.length - 1];
}

function getFileSizeString(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('HEAD', url, false);
    xhr.send();
    if (xhr.status === 200) {
        var fileSize = xhr.getResponseHeader('Content-Length');
        return formatBytes(fileSize);
    }
    return 'Unknown';
}

function showProgressBar() {
    var progressBar = document.getElementById('progress-bar');
    progressBar.style.display = 'block';
}

function hideProgressBar() {
    var progressBar = document.getElementById('progress-bar');
    progressBar.style.display = 'none';
}

function updateProgressBar(percentComplete) {
    var progressBarInner = document.getElementById('progress-bar-inner');
    progressBarInner.style.width = percentComplete + '%';
    progressBarInner.innerText = percentComplete.toFixed(1) + '%';
}

function formatBytes(bytes, decimals = 2) {
    if (bytes === 0) return '0 Bytes';
    var k = 1024;
    var dm = decimals < 0 ? 0 : decimals;
    var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
    var i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
}

function getFileExtension(filename) {
    return filename.slice((filename.lastIndexOf('.') - 1 >>> 0) + 2);
}

function groupImagesByExtension(urls) {
    var groups = {};
    for (var i = 0; i < urls.length; i++) {
        var url = urls[i];
        var ext = getFileExtension(url).toLowerCase();
        if (!groups[ext]) {
            groups[ext] = [];
        }
        groups[ext].push(url);
    }
    return groups;
}

var imageForm = document.getElementById('image-form');
imageForm.addEventListener('submit', convertImages);
downloadButtonZip.addEventListener('click', downloadZipImages);
</script>


<script>

  function groupImagesByExtension(images) {
    var extensionGroups = {};
    for (var i = 0; i < images.length; i++) {
      var img = images[i];
      var ext = img.substr(img.lastIndexOf('.') + 1);
      if (!extensionGroups[ext]) {
        extensionGroups[ext] = [];
      }
      extensionGroups[ext].push(img);
    }
    return extensionGroups;
  }

  convertButton.addEventListener('click', convertImages);

  downloadButton.addEventListener('click', function() {
    var images = resultDiv.querySelectorAll('img');
    for (var i = 0; i < images.length; i++) {
      var img = images[i];
      var link = document.createElement('a');
      link.href = img.src;
      link.download = img.src.substr(img.src.lastIndexOf('/') + 1);
      link.click();
    }
  });

  function getFileExtension(filename) {
    return filename.split('.').pop();
  }

// Add event listener to the "Download All" button
var downloadAllButton = document.getElementById('download');
downloadAllButton.addEventListener('click', downloadAllImages);

var downloadAllButton = document.getElementById('download-zip');
downloadAllButton.addEventListener('click', downloadAllImages);

function downloadAllImages() {
  var images = resultDiv.querySelectorAll('img');
  if (images.length === 0) {
    alert('No images to download.');
    return;
  }

  var zip = new JSZip();
  var promises = [];

  for (var i = 0; i < images.length; i++) {
    (function() {
      var img = images[i];
      var url = img.src;
      var fileName = getFileNameFromUrl(url);
      var dataPromise = fetch(url)
        .then(function(response) {
          return response.blob();
        })
        .then(function(blob) {
          zip.file(fileName, blob);
        });

      promises.push(dataPromise);
    })();
  }

  Promise.all(promises)
    .then(function() {
      return zip.generateAsync({ type: 'blob' });
    })
    .then(function(content) {
      var link = document.createElement('a');
      link.href = URL.createObjectURL(content);
      link.download = 'resized_images.zip';
      link.click();
    })
    .catch(function(error) {
      console.error('Error occurred during ZIP file generation:', error);
      alert('Failed to generate ZIP file.');
    });
}

</script>

<script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.7.1/jszip.min.js"></script>
<!-- Bootstrap JS -->
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.0/js/bootstrap.min.js"></script>

</body>

</html>

