
<?php
require_once('plugins/tcpdf/tcpdf.php');

function convertImageToPdf($imagePath, $pdf) {
    // Load the image and get its dimensions
    list($width, $height, $type, $attr) = getimagesize($imagePath);

    // Calculate the dimensions to fit the image on the page while maintaining the aspect ratio
    $pageWidth = $pdf->getPageWidth() - $pdf->getMargins()['left'] - $pdf->getMargins()['right'];
    $pageHeight = $pdf->getPageHeight() - $pdf->getMargins()['top'] - $pdf->getMargins()['bottom'];

    $imageWidth = $width;
    $imageHeight = $height;

    // Calculate the aspect ratio
    $aspectRatio = $width / $height;

    // Calculate the maximum image width and height based on the available page space
    $maxImageWidth = $pageWidth;
    $maxImageHeight = $pageHeight;

    if ($aspectRatio > 1) {
        // Landscape image
        if ($imageWidth > $maxImageWidth) {
            $imageWidth = $maxImageWidth;
            $imageHeight = $imageWidth / $aspectRatio;
        }
    } else {
        // Portrait image
        if ($imageHeight > $maxImageHeight) {
            $imageHeight = $maxImageHeight;
            $imageWidth = $imageHeight * $aspectRatio;
        }
    }

    // Calculate the position to center the image on the page
    $marginLeft = 10; // Adjust the margin value as needed
    $x = ($pageWidth - $imageWidth) / 2 + $marginLeft;
    $marginTop = 10; // Adjust the margin value as needed
    $y = ($pageHeight - $imageHeight) / 2 + $marginTop;

    // Add a new page
    $pdf->AddPage();

    // Add the image to the PDF
    $pdf->Image($imagePath, $x, $y, $imageWidth, $imageHeight, '', '', '', false, 300, '', false, false, 0, false, false, false);
}

function generateUniqueCode($length = 6) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $code = '';

    for ($i = 0; $i < $length; $i++) {
        $code .= $characters[rand(0, strlen($characters) - 1)];
    }

    return $code;
}

// Generate unique code
$uniqueCode = generateUniqueCode();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $extensions = array('jpg', 'jpeg', 'png', 'gif', 'bmp', 'webp', 'psd', 'tiff');
    $extension = 'image/png'; // Only converting to PDF, so set the output format to PDF

    if (isset($_FILES['image'])) {
        $files = $_FILES['image'];
        $totalFiles = count($files['name']);
        $urls = [];
        $pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);

        // Set document information
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetAuthor('Your Name');
        $pdf->SetTitle('Image to PDF Conversion');
        $pdf->SetSubject('Converting multiple images to a merged PDF using TCPDF');
        $pdf->SetKeywords('image, pdf, conversion');

        for ($i = 0; $i < $totalFiles; $i++) {
            $tempFilePath = $files['tmp_name'][$i];
            $fileName = $files['name'][$i];
            $fileExtension = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));

            if (in_array($fileExtension, $extensions)) {
                convertImageToPdf($tempFilePath, $pdf);
            }
        }

        // Output the merged PDF as a file]
        $mergedOutputPath = 'output/all_images_' . $uniqueCode . '.pdf';
        $pdf->Output($_SERVER['DOCUMENT_ROOT'] . '/tools/handytools/' . $mergedOutputPath, 'F');

       // Create individual PDFs for each image
$individualOutputPaths = [];
for ($i = 0; $i < $totalFiles; $i++) {
    $tempFilePath = $files['tmp_name'][$i];
    $fileName = $files['name'][$i];
    $fileExtension = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));

    if (in_array($fileExtension, $extensions)) {
        $individualPdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);
        convertImageToPdf($tempFilePath, $individualPdf);
        $individualOutputPath = 'output/converted_' . $uniqueCode . '__' . $fileName . '_' . ($i + 1) . '.pdf';
        $individualPdf->Output($_SERVER['DOCUMENT_ROOT'] . '/tools/handytools/' . $individualOutputPath, 'F');
        $individualOutputPaths[] = $individualOutputPath;
    }
}


        echo json_encode([
            'success' => true,
            'uniqueCode' => $uniqueCode,
            'mergedLink' => $mergedOutputPath,
            'individualLinks' => $individualOutputPaths,
        ]);
        exit;
    }

    echo json_encode([
        'success' => false,
        'message' => 'Conversion failed. Please try again.',
    ]);
    exit;
}
?>



<?php include"header.php"?>
<?php include"nav.php"?>


  
  <div class="container" style="background: rgb(255 255 255 / 90%);padding: 18px;
">
    <div class="row">
      <div class="col-md-6 mx-auto">
        <h3 style="text-align: center;">Batch Image to PDF Converter & Merger.</h3>
        <!-- <p style="text-align: center;">Convert your images to pdf or merge your multiple images into one pdf file</p> -->
  <div id="dropzone">
    <p>Drag and drop image files here</p>
    <form id="fileForm" method="post" enctype="multipart/form-data">
      <input type="file" id="fileInput" name="image[]" style="display: none;" accept="image/*" multiple>
    </form>
    <button id="browse" class="btn btn-primary" onclick="document.getElementById('fileInput').click()">Browse Files</button>
  </div>

  <div id="process-list"></div>

  <center><button id="convert" class="btn btn-success" style="width:300px;">Convert to PDF</button></center>

  <br>

  <div id="progress-bar" class="progress" style="display: none;">
    <div id="progress-bar-inner" class="progress-bar" role="progressbar" style="width: 0;"></div>
  </div>

  <div id="result"></div>
  
  <div style="display: flex; justify-content: space-between;">
<button id="downloadSingle" style="display: none;" class="btn btn-primary me-2">Download Single PDF</button>
<button id="downloadMerged" style="display: none;" class="btn btn-primary">Download Merged PDF</button>
</div>
</div>
<div id="process-list" style="display: none;"></div>

 </div>
    </div>
  </div>
  

 <?php include"includes/ad_header.php"?>
 
 </div>
  <style>
.more-tools {
  margin-top: 20px;
}

.more-tools-h2 {
  text-align: center;
  font-size: 24px;
  margin-bottom: 20px;
}

.more-tools-tool-container-wrapper {
  display: flex;
  justify-content: center;
}

.more-tools-tool-container {
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
}

.more-tools-tool {
  width: 200px;
  margin: 10px;
  padding: 20px;
  border: 1px solid #ccc;
  border-radius: 5px;
  text-align: center;
}

.more-tools-tool a {
  text-decoration: none;
  color: #007bff;
}

.more-tools-thumbnail {
  width: 100px;
  height: 100px;
  background-color: #f0f0f0;
  border-radius: 50%;
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 0 auto;
}

.more-tools-thumbnail i {
  font-size: 40px;
  color: #555555;
}

.more-tools-name {
  margin-top: 10px;
  font-size: 16px;
}

</style>


  <?php include"more_tools.php"?>
  <div class="container" id="faq">
  <?php include"mostafa-content.php"?>
</div>
<?php include"footer.php"?>
<script>
  var dropzone = document.getElementById('dropzone');
  var processList = document.getElementById('process-list');
  var convertButton = document.getElementById('convert');
  var fileInput = document.getElementById('fileInput');
  var progressBar = document.getElementById('progress-bar');
  var progressBarInner = document.getElementById('progress-bar-inner');
  var resultDiv = document.getElementById('result');
  var downloadSingleButton = document.getElementById('downloadSingle');
  var downloadMergedButton = document.getElementById('downloadMerged');
  var selectedFiles = [];
  var allowedExtensions = ['jpg', 'jpeg', 'png', 'gif']; // Add more allowed extensions if needed
  var response = null; // Declare response variable at higher scope
  var uniqueCode = "<?php echo $uniqueCode; ?>"; // Assign unique code value

  // Hide the process list initially
  processList.style.display = 'none';

  dropzone.addEventListener('dragover', function (e) {
    e.preventDefault();
    dropzone.style.border = '2px dashed #aaa';
  });

  dropzone.addEventListener('dragleave', function () {
    dropzone.style.border = '2px dashed #ccc';
  });

  dropzone.addEventListener('drop', function (e) {
    e.preventDefault();
    dropzone.style.border = '2px dashed #ccc';
    processList.innerHTML = '';
    selectedFiles = [];
    convertButton.disabled = true;

    var files = e.dataTransfer.files;
    displaySelectedFiles(files);
  });

  fileInput.addEventListener('change', function () {
    var files = fileInput.files;
    displaySelectedFiles(files);
  });

  function displaySelectedFiles(files) {
    if (files.length === 0) {
      alert('Please select image file(s).');
      return;
    }

    processList.style.display = 'block'; // Show the process list

    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var fileExtension = getFileExtension(file.name);

      if (!allowedExtensions.includes(fileExtension.toLowerCase())) {
        alert('Invalid extension. Skipping file: ' + file.name);
        continue;
      }

     selectedFiles.push(file);

var listItem = document.createElement('li');
listItem.classList.add('d-flex', 'align-items-center', 'justify-content-between');
listItem.style.padding = '10px';

var imageContainer = document.createElement('div');
imageContainer.innerHTML = `
  <img src="${URL.createObjectURL(file)}" alt="Image" style="width: 80px; height: 80px;">
`;

var fileInfoContainer = document.createElement('div');
fileInfoContainer.style.fontSize = '12px';
fileInfoContainer.style.paddingLeft = '10px';
fileInfoContainer.innerHTML = `
  <span>${file.name}</span>
  <span style="color: #7a7c7e;">(${formatFileSize(file.size)})</span>
`;

var removeButton = document.createElement('button');
removeButton.innerText = 'Remove';
removeButton.classList.add('btn', 'btn-warning', 'btn-sm');
removeButton.dataset.index = i;
removeButton.addEventListener('click', removeSelectedFile);

listItem.appendChild(imageContainer);
listItem.appendChild(fileInfoContainer);
listItem.appendChild(removeButton);
processList.appendChild(listItem);

}

    if (selectedFiles.length > 0) {
      convertButton.disabled = false;
    }
  }

  function removeSelectedFile(event) {
    var index = event.target.dataset.index;
    selectedFiles.splice(index, 1);
    processList.removeChild(event.target.parentNode);

    if (selectedFiles.length === 0) {
      convertButton.disabled = true;
      processList.style.display = 'none';
    }
  }

  function convertImages() {
    if (selectedFiles.length === 0) {
      alert('Please select image file(s).');
      return;
    }

    var formData = new FormData();

    for (var i = 0; i < selectedFiles.length; i++) {
      formData.append('image[]', selectedFiles[i]);
    }

    var xhr = new XMLHttpRequest();
    xhr.open('POST', '<?php echo $_SERVER["PHP_SELF"]; ?>', true);

    // Track upload progress
    xhr.upload.addEventListener('progress', function (event) {
      if (event.lengthComputable) {
        var percentComplete = (event.loaded / event.total) * 100;
        updateProgressBar(percentComplete);
      }
    });

    xhr.onreadystatechange = function () {
      if (xhr.readyState === XMLHttpRequest.DONE) {
        hideProgressBar(); // Hide the progress bar once the request is complete

        if (xhr.status === 200) {
          response = JSON.parse(xhr.responseText); // Assign response value
          if (response.success) {
            resultDiv.innerHTML = '<div class="alert alert-success text-center">Conversion successful!</div>';
            downloadSingleButton.style.display = 'block';
            downloadMergedButton.style.display = 'block';
          } else {
            resultDiv.innerHTML = '<div class="alert alert-danger text-center">Conversion failed. Please try again.</div>';
          }
        } else {
          resultDiv.innerHTML = '<div class="alert alert-danger text-center">Conversion failed. Please try again.</div>';
        }

      }
    };

    // Show the progress bar
    showProgressBar();

    xhr.send(formData);
  }

  function showProgressBar() {
    progressBar.style.display = 'block';
  }

  function hideProgressBar() {
    progressBar.style.display = 'none';
  }

  function updateProgressBar(percentComplete) {
    progressBarInner.style.width = percentComplete + '%';
    progressBarInner.innerText = percentComplete.toFixed(1) + '%';
  }

  function getFileExtension(filename) {
    return filename.split('.').pop();
  }

  function formatFileSize(size) {
    var units = ['B', 'KB', 'MB', 'GB', 'TB'];
    var i = 0;
    while (size >= 1024 && i < units.length - 1) {
      size /= 1024;
      i++;
    }
    return size.toFixed(2) + ' ' + units[i];
  }

  function downloadSinglePDF() {
    if (response && response.individualLinks) {
      var individualLinks = response.individualLinks;
      for (var i = 0; i < individualLinks.length; i++) {
        var link = document.createElement('a');
        link.href = individualLinks[i];
        var originalFileName = selectedFiles[i].name;
        var filename = 'converted_' + response.uniqueCode + '_' + originalFileName + '_' + (i + 1) + '.pdf';
        link.download = filename;
        link.click();
      }
    }
  }

  function downloadMergedPDF() {
    if (response && response.mergedLink) {
      var mergedLink = response.mergedLink;
      var link = document.createElement('a');
      link.href = mergedLink;
      var filename = 'merged_images_' + response.uniqueCode + '.pdf';
      link.download = filename;
      link.click();
    }
  }

  convertButton.addEventListener('click', convertImages);
  downloadSingleButton.addEventListener('click', downloadSinglePDF);
  downloadMergedButton.addEventListener('click', downloadMergedPDF);
</script>

</body>
</html>
