
var units = {
  Length: [
    ["Meter", "m", 1],
    ["Kilometer", "km", 1000],
    ["Centimeter", "cm", 0.01],
    ["Millimeter", "mm", 0.001],
    ["Micrometer", "µm", 0.000001],
    ["Nanometer", "nm", 0.000000001],
    ["Mile", "mi", 1609.344],
    ["Yard", "yd", 0.9144],
    ["Foot", "ft", 0.3048],
    ["Inch", "in", 0.0254],
    ["Light Year", "ly", 9.461e15]
  ],
  BitsBytes: [
    ["bits", "b", 0.125],
    ["bytes", "B", 1],
    ["kilobits", "Kb", 128],
    ["kilobytes", "KB", 1024],
    ["megabits", "Mb", 131072],
    ["megabytes", "MB", 1048576],
    ["gigabits", "Gb", 134217728],
    ["gigabytes", "GB", 1073741824],
    ["terabits", "Tb", 137438953472],
    ["terabytes", "TB", 1099511627776],
    ["petabits", "Pb", 140737488355328],
    ["petabytes", "PB", 1125899906842624],
    ["exabits", "Eb", 144115188075855872],
    ["exabytes", "EB", 1152921504606846976]
  ],
  Temperature: [
    ["Celsius", "°C", 1],
    ["Kelvin", "K", function(value, to) { return to ? value + 273.15 : value - 273.15; }],
    ["Fahrenheit", "°F", function(value, to) { return to ? (value * 9/5) + 32 : (value - 32) * 5/9; }]
  ],
  Area: [
    ["Square Meter", "m²", 1],
    ["Square Kilometer", "km²", 1000000],
    ["Square Centimeter", "cm²", 0.0001],
    ["Square Millimeter", "mm²", 0.000001],
    ["Square Micrometer", "µm²", 0.000000000001],
    ["Hectare", "ha", 10000],
    ["Square Mile", "mi²", 2590000],
    ["Square Yard", "yd²", 0.83612736],
    ["Square Foot", "ft²", 0.09290304],
    ["Square Inch", "in²", 0.00064516],
    ["Acre", "ac", 4046.8564224]
  ],
  Volume: [
    ["Cubic Meter", "m³", 1],
    ["Cubic Kilometer", "km³", 1000000000],
    ["Cubic Centimeter", "cm³", 0.000001],
    ["Cubic Millimeter", "mm³", 0.000000001],
    ["Liter", "L", 0.001],
    ["Milliliter", "mL", 0.000001],
    ["US Gallon", "gal", 0.00378541],
    ["US Quart", "qt", 0.0009463525],
    ["US Pint", "pt", 0.00047317625],
    ["US Cup", "cup", 0.000236588125],
    ["US Fluid Ounce", "fl oz", 0.000029573515625],
    ["US Table Spoon", "Tbsp", 0.0000147867578125],
    ["US Tea Spoon", "tsp", 0.00000492891927083333],
    ["Imperial Gallon", "gal", 0.00454609],
    ["Imperial Quart", "qt", 0.0011365225],
    ["Imperial Pint", "pt", 0.00056826125],
    ["Imperial Fluid Ounce", "fl oz", 0.0000284130625],
    ["Imperial Table Spoon", "Tbsp", 0.0000177581640625],
    ["Imperial Tea Spoon", "tsp", 0.00000591938802083333],
    ["Cubic Mile", "mi³", 4168180000],
    ["Cubic Yard", "yd³", 0.764554857984],
    ["Cubic Foot", "ft³", 0.028316846592],
    ["Cubic Inch", "in³", 0.000016387064]
  ],
  Weight: [
    ["Kilogram", "kg", 1],
    ["Gram", "g", 0.001],
    ["Milligram", "mg", 0.000001],
    ["Metric Ton", "t", 1000],
    ["Long Ton", "ton", 1016.0469088],
    ["Short Ton", "ton", 907.18474],
    ["Pound", "lb", 0.45359237],
    ["Ounce", "oz", 0.0283495231],
    ["Carrat", "ct", 0.0002],
    ["Atomic Mass Unit", "u", 1.6605401999104288e-27]
  ],
  Time: [
    ["Second", "s", 1],
    ["Millisecond", "ms", 0.001],
    ["Microsecond", "µs", 0.000001],
    ["Nanosecond", "ns", 0.000000001],
    ["Picosecond", "ps", 0.000000000001],
    ["Minute", "min", 60],
    ["Hour", "hr", 3600],
    ["Day", "day", 86400],
    ["Week", "wk", 604800],
    ["Month", "mo", 2629800], // Average length in seconds: 30.436875 days * 24 hours * 60 minutes * 60 seconds
    ["Year", "yr", 31536000]
  ],
  Currency: [] // Initialize empty array for currency conversions
};

// Fetch currency exchange rates from ECB API
function fetchCurrencyRates() {
  var url = 'https://api.exchangerate-api.com/v4/latest/EUR';

  fetch(url)
    .then(function(response) {
      return response.json();
    })
    .then(function(data) {
      // Update the units object with currency conversions
      units.Currency = Object.entries(data.rates).map(function(rate) {
        return [rate[0], rate[0], rate[1]]; // [Currency, Currency, Rate]
      });

      // Call the loadQuantity function to update the currency options
      loadQuantity();
    })
    .catch(function(error) {
      console.log('Error fetching currency rates:', error);
    });
}

// Load the quantity options
function loadQuantity() {
  var selectQuantity = document.getElementById("selectQuantity");
  var selectFrom = document.getElementById("selectFrom");
  var selectTo = document.getElementById("selectTo");

  var quantity = selectQuantity.value;
  var options = "";

  for (var i = 0; i < units[quantity].length; i++) {
    var unitName = units[quantity][i][0];
    var unitShortForm = units[quantity][i][1];
    options += '<option value="' + i + '">' + unitName + ' (' + unitShortForm + ')' + '</option>';
  }

  selectFrom.innerHTML = options;
  selectTo.innerHTML = options;

  convert();
}

// Perform the conversion
function convert() {
  var selectQuantity = document.getElementById("selectQuantity");
  var selectFrom = document.getElementById("selectFrom");
  var selectTo = document.getElementById("selectTo");
  var inputFrom = document.getElementById("inputFrom").value;
  var inputTo = document.getElementById("inputTo");

  var quantity = selectQuantity.value;
  var fromIndex = selectFrom.value;
  var toIndex = selectTo.value;

  var fromUnit = units[quantity][fromIndex][2];
  var toUnit = units[quantity][toIndex][2];

  // Check if currency conversion is needed
  if (quantity === 'Currency') {
    var currencyFrom = units[quantity][fromIndex][0];
    var currencyTo = units[quantity][toIndex][0];

    // Fetch the current exchange rates and perform the conversion
    var url = 'https://api.exchangerate-api.com/v4/latest/EUR';
    fetch(url)
      .then(function(response) {
        return response.json();
      })
      .then(function(data) {
        var rates = data.rates;

        var baseRate = rates[currencyFrom];
        var targetRate = rates[currencyTo];

        var result = (parseFloat(inputFrom) / baseRate) * targetRate;

        inputTo.value = roundResult(result);
      })
      .catch(function(error) {
        console.log('Error fetching currency rates:', error);
      });
  } else {
    var result = parseFloat(inputFrom) * (fromUnit / toUnit);
    inputTo.value = roundResult(result);
  }
}

// Round the result to 6 decimal places
function roundResult(result) {
  return Number(result.toFixed(6));
}

// Add the fetchCurrencyRates() function call to initialize the currency rates
fetchCurrencyRates();

// Switch the result between "From" and "To"
function switchResult() {
  var inputFrom = document.getElementById("inputFrom");
  var inputTo = document.getElementById("inputTo");
  var selectFrom = document.getElementById("selectFrom");
  var selectTo = document.getElementById("selectTo");
  var switchButton = document.getElementById("switchButton");

  var tempValue = inputFrom.value;
  inputFrom.value = inputTo.value;
  inputTo.value = tempValue;

  tempValue = selectFrom.value;
  selectFrom.value = selectTo.value;
  selectTo.value = tempValue;

  if (switchButton.checked) {
    convertBack();
  } else {
    convert();
  }
}
